==> hermes-5.6.0.50.tar.gz: hermes-5.6.0.50/app/assets/docs/doc/06 - Company.md <==
# Entreprise

## Changer le manual mode d'une entreprise

    Le user doit avoir comme rôle superadministrateur.

    Si l'entity à un manual mode en true il changera en false et vice versa

        PUT /api/dmo/entities/{id}/switch_manual_mode

    params: id:

    retour json

        {status: "success", code: 200, message: "manual mode switch to true / false"}

## Affectations d'habilitation sur les entreprise et bailleurs
  3 types de droit sur une entreprise/bailleur :
  * `reader`
    * voir l'entreprise/bailleur dans son arborescence REX
  * `user`
    * les droits de `reader`
    * peut modifier les informations de l'entreprise
  * `administrator` :
    * les droits de `user`
    * créer des habilitation sur les entreprises/bailleurs dont il a les droits

  Pour créer une habilitation sur une entreprise ou bailleur :

      POST /api/dmo/user_rights
        data: {
          attributes: {
              right: 'administrator',
              type: 'entity',
              entity_id: entity_id,
              user_email: 'new_user@email.com',
              user_first_name: 'John',
              user_last_name: 'Doe',
              user_auth_roles: ['bailleur'],
              user_gender: 'M',
              user_phone_number: '1234567890',
            }
          }
        }
      Le champs user_email est utilisé pour récupérer l'utilisateur si il existe
      Si il n'existe pas les champs user_email, user_first_name, user_last_name, user_auth_roles sont obligatoires pour créer l'utilisateur.

  Pour supprimer une habilitations 

    DELETE /api/dmo/user_rights/:id

  Pour récupérer les habilitations, il existe 2 méthodes :

  * Sur les entity et lessor un champs `current_user_right`
  * Une route GET /api/dmo/user_rights avec la possibilité de filtrer par entity_id, lessor_id, user_id, right, type

  Pour supprimer plusieurs user_rights: 

    DELETE /api/dmo/user_rights/bulk
    {
      user_right_ids: [id1, id2, id3, ...]
    }

  Pour supprimer tous les user_rights d'un utilisateur:

    DELETE /api/dmo/user_rights/all_from_user
    {
      user_id: id
    }

  Pour ajouter plusieurs user_rights :

    POST /api/dmo/user_rights/bulk
    {
      user_rights: [
        {user_email: email, entity_id: id, right: 'administrator', type: 'entity'},
        {user_email: email, entity_id: id, right: 'administrator', type: 'entity'},
        {user_email: email, entity_id: id, right: 'administrator', type: 'entity'},
      ]
    }

  Pour rechercher sans limite de paramètres :

    POST /api/dmo/user_rights/search
    {
      'entity_id': {
        '$in': [id1, id2, id3, ...]
      }
    }
 
 Pour savoir si un utilisateur est administrateur sur une entreprise ou bailleur :

    Un paramètre user_id peut être utilsié sinon on utilise l'utilsiateur connecté.
    
    GET /api/dmo/user_rights/is_administrator_for_lessor
    GET /api/dmo/user_rights/is_administrator_for_entity?user_id=:id
    Retour:
      {
        is_administrator: true
      }
    
  Appel pour récupérer la plus haute habillitations des utilsiateurs ayant des droits sur un ensemble de d'entreprise/bailleur
    
    POST /api/dmo/user_rights/all_users_with_rights
    {
      "entity_id": {
        "$in": {
          ['id1', 'id2']
        }
    }
    Retour => 
      {
        "data": {
          "attributes": [
            {"id": "id1", "type": 'hermes-user_rights' ....}
            {"id": "id2", "type": 'hermes-user_rights' ....}

          ]
        }
      }

  Et l'appel pour récupérer la liste des habillitations d'un utilisateur sur une liste d'entreprise

      POST /api/dmo/user_rights/search
      {
        "user_id": "id1",
        "entity_id": {
          "$in": {
            ['id1', 'id2']
          }
      }
      Retour => 
        {
          "data": {
            "attributes": [
              {"id": "id1", "type": 'hermes-user_rights' ....}
              {"id": "id2", "type": 'hermes-user_rights' ....}

            ]
          }
        }



## Entreprises

### Validation des matricules

**Ce modèle est nommé `EntityValidation`**

La validation de matricule est le fait pour une entrprise de valider qu'un salarier travaille bien pour elle et que le contrat est toujours actif.

Pour ce qui est des validations via matricule, cela concerne surtout les demandes et non les requalifications.
Le matricule n'étant pas un champ SNE, on ne l'aura pas pour une requalification, donc on passe forcément par l'attente d'une validation manuelle (cas par défaut).

La mise à jour de la date de fin de contrat declenche un job (à date) qui enlèvera l'entreprise de la demande et invalidera la candidature en cours

#### Liste des champs

|Name|Type|Editable|Format|Default|Infos
|---|---|---|---|---|---|---|
|entity_id|:string|false|`"5e4fdc8b3604e9cfbf4d055e"`|auto|Entreprise lié à l'utilisateur courant|
|applicant_id|:string|true|`"5e4fdc8b3604e9cfbf4d055e"`|null|Obligatoire lors de la création|
|identification_number|:string|true|`"5e4fdc8b3604e9cfbf4d055e"`|null|Obligatoire lors de la création|
|civility|:string|true|`"Mr", "Mme", "Mlle"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|first_name|:string|true|`"Jhon"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|last_name|:string|true|`"DOE"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|birth_date|:string|true|`"2020-08-24"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|validation|:booleen|true|`true, false`|entity.auto_validation ou true|création/mise à jour|
|contract_start_date|:string|true|`"2020-08-24"`|null|création/mise à jour|
|contract_end_date|:string|true|`"2020-08-24"`|null|création/mise à jour|
|active|:booleen|false|`true, false`|auto|`true` si contract_start_date <= Date.today et contract_end_date > Date.today|
Lorsqu'une erreur se produit lors de l'appel d'un flux sopra, un log emmetant un evenement websocket est produit. ce log contient l'url appelée ainsi que le retour erreur du webservice sopra.

### Validation des demandes

**Attention à ne pas confondre avec la validation de matricule**

Par défaut, chaque entreprise est créée avec un champ `:auto_request_validation` à `true` ce champ est utilisé pour valider de manière automatique chaque demande émise par les salariers de l'entreprise `housing_request.entity_validated`.

Le champ `:auto_request_validation` peut êtrer modifié par les utilisateurs ayant un droit d'écriture sur l'entreprise.

*Voir **Validation du salarié par l'entreprise** pour les validations manuelles unitaire*

==> hermes-5.7.0.10.tar.gz: hermes-5.7.0.10/app/assets/docs/doc/06 - Company.md <==
# Entreprise

## Changer le manual mode d'une entreprise

    Le user doit avoir comme rôle superadministrateur.

    Si l'entity à un manual mode en true il changera en false et vice versa

        PUT /api/dmo/entities/{id}/switch_manual_mode

    params: id:

    retour json

        {status: "success", code: 200, message: "manual mode switch to true / false"}

## Affectations d'habilitation sur les entreprise et bailleurs
  3 types de droit sur une entreprise/bailleur :
  * `reader`
    * voir l'entreprise/bailleur dans son arborescence REX
  * `user`
    * les droits de `reader`
    * peut modifier les informations de l'entreprise
  * `administrator` :
    * les droits de `user`
    * créer des habilitation sur les entreprises/bailleurs dont il a les droits

  Pour créer une habilitation sur une entreprise ou bailleur :

      POST /api/dmo/user_rights
        data: {
          attributes: {
              right: 'administrator',
              type: 'entity',
              entity_id: entity_id,
              user_email: 'new_user@email.com',
              user_first_name: 'John',
              user_last_name: 'Doe',
              user_auth_roles: ['bailleur'],
              user_gender: 'M',
              user_phone_number: '1234567890',
            }
          }
        }
      Le champs user_email est utilisé pour récupérer l'utilisateur si il existe
      Si il n'existe pas les champs user_email, user_first_name, user_last_name, user_auth_roles sont obligatoires pour créer l'utilisateur.

  Pour supprimer une habilitations 

    DELETE /api/dmo/user_rights/:id

  Pour récupérer les habilitations, il existe 2 méthodes :

  * Sur les entity et lessor un champs `current_user_right`
  * Une route GET /api/dmo/user_rights avec la possibilité de filtrer par entity_id, lessor_id, user_id, right, type

  Pour supprimer plusieurs user_rights: 

    DELETE /api/dmo/user_rights/bulk
    {
      user_right_ids: [id1, id2, id3, ...]
    }

  Pour supprimer tous les user_rights d'un utilisateur:

    DELETE /api/dmo/user_rights/all_from_user
    {
      user_id: id
    }

  Pour ajouter plusieurs user_rights :

    POST /api/dmo/user_rights/bulk
    {
      user_rights: [
        {user_email: email, entity_id: id, right: 'administrator', type: 'entity'},
        {user_email: email, entity_id: id, right: 'administrator', type: 'entity'},
        {user_email: email, entity_id: id, right: 'administrator', type: 'entity'},
      ]
    }

  Pour rechercher sans limite de paramètres :

    POST /api/dmo/user_rights/search
    {
      'entity_id': {
        '$in': [id1, id2, id3, ...]
      }
    }
 
 Pour savoir si un utilisateur est administrateur sur une entreprise ou bailleur :

    Un paramètre user_id peut être utilsié sinon on utilise l'utilsiateur connecté.
    
    GET /api/dmo/user_rights/is_administrator_for_lessor
    GET /api/dmo/user_rights/is_administrator_for_entity?user_id=:id
    Retour:
      {
        is_administrator: true
      }
    
  Appel pour récupérer la plus haute habillitations des utilsiateurs ayant des droits sur un ensemble de d'entreprise ou bailleur
    
    POST /api/dmo/user_rights/all_users_with_rights
    {
      "entity_id": {
        "$in": {
          ['id1', 'id2']
        }
    }
    ou 

    POST /api/dmo/user_rights/all_users_with_rights
    {
      "lessor_id": {
        "$in": {
          ['id1', 'id2']
        }
    }
    
    Retour => 
      {
        "data": {
          "attributes": [
            {"id": "id1", "type": 'hermes-user_rights' ....}
            {"id": "id2", "type": 'hermes-user_rights' ....}

          ]
        }
      }

  Et l'appel pour récupérer la liste des habillitations d'un utilisateur sur une liste d'entreprise

      POST /api/dmo/user_rights/search
      {
        "user_id": "id1",
        "entity_id": {
          "$in": {
            ['id1', 'id2']
          }
      }
      Retour => 
        {
          "data": {
            "attributes": [
              {"id": "id1", "type": 'hermes-user_rights' ....}
              {"id": "id2", "type": 'hermes-user_rights' ....}

            ]
          }
        }



## Entreprises

### Validation des matricules

**Ce modèle est nommé `EntityValidation`**

La validation de matricule est le fait pour une entrprise de valider qu'un salarier travaille bien pour elle et que le contrat est toujours actif.

Pour ce qui est des validations via matricule, cela concerne surtout les demandes et non les requalifications.
Le matricule n'étant pas un champ SNE, on ne l'aura pas pour une requalification, donc on passe forcément par l'attente d'une validation manuelle (cas par défaut).

La mise à jour de la date de fin de contrat declenche un job (à date) qui enlèvera l'entreprise de la demande et invalidera la candidature en cours

#### Liste des champs

|Name|Type|Editable|Format|Default|Infos
|---|---|---|---|---|---|---|
|entity_id|:string|false|`"5e4fdc8b3604e9cfbf4d055e"`|auto|Entreprise lié à l'utilisateur courant|
|applicant_id|:string|true|`"5e4fdc8b3604e9cfbf4d055e"`|null|Obligatoire lors de la création|
|identification_number|:string|true|`"5e4fdc8b3604e9cfbf4d055e"`|null|Obligatoire lors de la création|
|civility|:string|true|`"Mr", "Mme", "Mlle"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|first_name|:string|true|`"Jhon"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|last_name|:string|true|`"DOE"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|birth_date|:string|true|`"2020-08-24"`|null|Récupéré sur le candidat si aucun de [civility, first_name, last_name, birth_date] n'est fournit à la création|
|validation|:booleen|true|`true, false`|entity.auto_validation ou true|création/mise à jour|
|contract_start_date|:string|true|`"2020-08-24"`|null|création/mise à jour|
|contract_end_date|:string|true|`"2020-08-24"`|null|création/mise à jour|
|active|:booleen|false|`true, false`|auto|`true` si contract_start_date <= Date.today et contract_end_date > Date.today|
Lorsqu'une erreur se produit lors de l'appel d'un flux sopra, un log emmetant un evenement websocket est produit. ce log contient l'url appelée ainsi que le retour erreur du webservice sopra.

### Validation des demandes

**Attention à ne pas confondre avec la validation de matricule**

Par défaut, chaque entreprise est créée avec un champ `:auto_request_validation` à `true` ce champ est utilisé pour valider de manière automatique chaque demande émise par les salariers de l'entreprise `housing_request.entity_validated`.

Le champ `:auto_request_validation` peut êtrer modifié par les utilisateurs ayant un droit d'écriture sur l'entreprise.

*Voir **Validation du salarié par l'entreprise** pour les validations manuelles unitaire*
